# SupportRequestAcknowledgementStatus

The current status of the support request acknowledgement. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**supporting_user_email** | [**Email**](Email.md) |  | 
**expiry** | **datetime** | Expiry date of the acknowledged support request in UTC. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


